@@ -1,5 +1,3 @@
-context("Initialize mverse")
-
 test_that("Instantiation works with a data frame (mverse).", {
   mydf <- data.frame(col1 = c(1, 2, 3))
   mv <- mverse(mydf)
@@ -12,9 +10,11 @@ test_that("Instantiation works with a data frame (create_multiverse).", {
   expect_equal(attr(mv, "source"), mydf)
 })
 
-test_that("Initializing with an object that is not a data frame throws an error.", {
-  a_list <- list("a", "b", "c")
-  expect_error(mv <- mverse(a_list))
-  an_arrary <- c("a", "b", "c")
-  expect_error(mv <- mverse(an_array))
-})
+test_that(
+  "Initializing with an object that is not a data frame throws an error.", {
+    a_list <- list("a", "b", "c")
+    expect_error(mv <- mverse(a_list))
+    an_arrary <- c("a", "b", "c")
+    expect_error(mv <- mverse(an_array))
+  }
+)
